@@ -23,7 +23,7 @@ def optimize_hyperparams(hyperparams: list, data, func: str, n_steps=1, n_splits
 
     Warning: Can be computationally intensive, try with a single combination of `hyperparams` and `runs_per_split=1` first.
 
-    Can also be used for CV, use with the best hyperparameters and `runs_per_split=1`.
+    Can also be used for evaluating model performance using CV (use with the best hyperparameters and `runs_per_split=1`).
 
     :param hyperparams: A list/dict of one combination of hyperparameters to be tried out (look into the particular function to use for the structure it should have).
     :param data: A DataFrame or Series with a continuous index and one column with the data (for SARIMAX has to be the first with
@@ -44,7 +44,7 @@ def optimize_hyperparams(hyperparams: list, data, func: str, n_steps=1, n_splits
         rmse = list()
         for i in range(0, runs_per_split):
             try:
-                preds = globals()[func](hyperparams, cv_train, n_steps)
+                preds = globals()[func](hyperparams, cv_train, n_steps, cv_test)
             except:
                 print(hyperparams)
                 traceback.print_exc()
@@ -71,7 +71,7 @@ def sort_results(results_list):
     return sorted(results_list, key=lambda k: tuple(k.get(key, "") for key in sorted(k)))
 
 
-def exp_smoothing(hyperparams, cv_train, n_steps):
+def exp_smoothing(hyperparams, cv_train, n_steps, cv_test):
     return ExponentialSmoothing(
         cv_train.astype(float),
         seasonal_periods=hyperparams["periods"],
@@ -83,7 +83,7 @@ def exp_smoothing(hyperparams, cv_train, n_steps):
     ).fit(remove_bias=hyperparams["remove_bias"]).simulate(n_steps, repetitions=100, error="mul").mean(axis=1)
 
 
-def sarima(hyperparams, cv_train, n_steps):
+def sarima(hyperparams, cv_train, n_steps, cv_test):
     return SARIMAX(
         cv_train.astype(float),
         order=hyperparams[0],
@@ -91,7 +91,7 @@ def sarima(hyperparams, cv_train, n_steps):
     ).fit().forecast(steps=n_steps)
 
 
-def sarimax(hyperparams, cv_train, cv_test, n_steps):
+def sarimax(hyperparams, cv_train, n_steps, cv_test):
     return SARIMAX(
         endog=cv_train.iloc[:,0],
         exog=cv_train.iloc[:,1:],
